#include <amxmodx>
#include <amxmisc>
#include <cstrike>
//#include <fun>

// CVAR for the prefix (configurable in server configuration)
new g_prefix[32];
new g_balance_active = false;
new CsTeams:g_target_team = CS_TEAM_UNASSIGNED; // 1 for Terrorists, 2 for CT
new g_mp_autoteambalance;
new g_mp_limitteams;

// Plugin information
public plugin_init() {
    register_plugin("Clan vs. rest", "1.0", "mcs");

    // Register CVAR to make prefix configurable
    register_cvar("clan_prefix", "override_me");

    // Commands for admins (only admins with the ADMIN_BAN flag can execute them)
    register_concmd("amx_clan_vs_rest", "cmd_balance_teams", ADMIN_LEVEL_A, "<team> (t|ct|off)");
    register_logevent("logevent_round_end", 2, "1=Round_End");
}

// Load the prefix on plugin initialization
public plugin_cfg() {
    get_cvar_string("clan_prefix", g_prefix, charsmax(g_prefix));
    g_mp_autoteambalance = get_cvar_num("mp_autoteambalance");
    g_mp_limitteams = get_cvar_num("mp_limitteams");
    log_amx("Plugin loaded with clan prefix '%s'", g_prefix);
}

// Command to activate team balancing (only for admins)
public cmd_balance_teams(id, level, cid) {
    if (strcmp(g_prefix, "override_me") == 0) {
        console_print(id, "You must define your own clan prefix in amxx.cfg by setting the clan_prefix cvar.");
    }

    if (!cmd_access(id, ADMIN_LEVEL_A, cid, 1)) {
        console_print(id, "You don't have permission to use this command.");
        return PLUGIN_HANDLED;
    }

    // Read argument to determine if team T or CT
    new team[4];
    read_argv(1, team, sizeof(team));

    if (equali(team, "t")) {
        g_target_team = CS_TEAM_T;
    } else if (equali(team, "ct")) {
        g_target_team = CS_TEAM_CT;
    } else if (equali(team, "off")) {
        if (g_balance_active) {
            set_cvar_num("mp_autoteambalance", g_mp_autoteambalance);
            set_cvar_num("mp_limitteams", g_mp_limitteams);
        }
        g_balance_active = false;
        client_print(0, print_chat, "%s vs. them disabled. Team switching is possible again.", g_prefix);
        return PLUGIN_HANDLED;
    } else {
        console_print(id, "Usage: amx_clan_vs_rest [t|ct|off]");
        return PLUGIN_HANDLED;
    }

    if (!g_balance_active) {
        g_mp_autoteambalance = get_cvar_num("mp_autoteambalance");
        g_mp_limitteams = get_cvar_num("mp_limitteams");
    }

    set_cvar_num("mp_autoteambalance", 0);
    set_cvar_num("mp_limitteams", 0);
    g_balance_active = true;

    client_print(0, print_chat, "%s will exclusively play as %s after this round.", 
            g_prefix, (g_target_team == CS_TEAM_T) ? "T" : "CT");

    return PLUGIN_HANDLED;
}

// Apply balance to all connected players
public balance_all_players() {
    if (g_balance_active) {
        new max_players = get_maxplayers();

        for (new i = 1; i <= max_players; i++) {
            if (is_user_connected(i)) {
                balance_player(i);
            }
        }
        log_amx("Rebalanced %d players.", max_players);
    }
}

// Balance a specific player based on their prefix
public balance_player(id) {
    if (!is_user_connected(id)) {
        return;
    }

    new CsTeams:team = cs_get_user_team(id);
    if (team == CS_TEAM_SPECTATOR || team == CS_TEAM_UNASSIGNED) {
        // we don't move unassigned / spectating players
        return;
    }

    new name[32];
    get_user_name(id, name, charsmax(name));

    if (contain(name, g_prefix) == 0) {
        cs_set_user_team(id, g_target_team);
    } else {
        cs_set_user_team(id, (g_target_team == CS_TEAM_T) ? CS_TEAM_CT : CS_TEAM_T);
    }
}

public logevent_round_end() {
    if (g_balance_active) {
        set_task(4.9, "balance_all_players");
    }
}